@@ -6,7 +6,8 @@ import cv2
 
 def find_middle(x, y, w, h) -> tuple:
         '''
-        Supple
+        Function for finding the center of a rectangle
+        The center of rectangle is the midpoint of the diagonal end points of rectangle.
         '''
         x1, y1 = x, y
         x2, y2 = x + w, y + h
@@ -15,6 +16,9 @@ def find_middle(x, y, w, h) -> tuple:
 
 
 def find_radius(x, y, w, h) -> tuple:
+        '''
+        Function finds the distance between the center and side edge
+        '''
         pt1 = (x, y)
         pt2 = (x+w, y+h)
 
@@ -25,43 +29,35 @@ def find_radius(x, y, w, h) -> tuple:
         return dis
 
 
-def sap_noise(frame):
-    img = frame.copy()
-    # Getting the dimensions of the image
-    row , col, _ = img.shape
-     
-    # Randomly pick some pixels in the
-    # image for coloring them white
-    # Pick a random number between 300 and 10000
-    number_of_pixels = random.randint(5000, 10000)
-    for i in range(number_of_pixels):
-       
-        # Pick a random y coordinate
-        y_coord=random.randint(0, row - 1)
-         
-        # Pick a random x coordinate
-        x_coord=random.randint(0, col - 1)
-         
-        # Color that pixel to white
-        img[y_coord][x_coord] = 255
-         
-    # Randomly pick some pixels in
-    # the image for coloring them black
-    # Pick a random number between 300 and 10000
-    number_of_pixels = random.randint(5000 , 10000)
-    for i in range(number_of_pixels):
-       
-        # Pick a random y coordinate
-        y_coord=random.randint(0, row - 1)
-         
-        # Pick a random x coordinate
-        x_coord=random.randint(0, col - 1)
-         
-        # Color that pixel to black
-        img[y_coord][x_coord] = 0
-         
-    return img
-     
+def sap_noise(frame, seed = None):
+        random.seed(seed)
+        img = frame.copy()
+        # Getting the dimensions of the image
+        row , col, _ = img.shape
+        # Randomly pick some pixels in the
+        # image for coloring them white
+        # Pick a random number between 300 and 10000
+        number_of_pixels = random.randint(8000, 15000)
+        for i in range(number_of_pixels):
+                # Pick a random y coordinate
+                y_coord=random.randint(0, row - 1)
+                # Pick a random x coordinate
+                x_coord=random.randint(0, col - 1)
+                # Color that pixel to white
+                img[y_coord][x_coord] = 255
+        # Randomly pick some pixels in
+        # the image for coloring them black
+        # Pick a random number between 300 and 10000
+        number_of_pixels = random.randint(8000 , 15000)
+        for i in range(number_of_pixels):
+                # Pick a random y coordinate
+                y_coord=random.randint(0, row - 1)
+                # Pick a random x coordinate
+                x_coord=random.randint(0, col - 1)
+                # Color that pixel to black
+                img[y_coord][x_coord] = 0
+        return img
+
 
 def pixelated(image,  blocks = 20):
           (h, w) = image.shape[:2]
